@@ -32,9 +32,9 @@ phase2.1<- function(z, x, ...)
     z$writefreq <- 1
     if (!is.batch())
     {
-        tkconfigure(z$tkvars$earlyEndPhase2,state='normal')
-        tkconfigure(z$tkvars$subphase,state='normal')
-        tkconfigure(z$tkvars$subphaselabel,state='normal')
+        tcltk::tkconfigure(z$tkvars$earlyEndPhase2,state='normal')
+        tcltk::tkconfigure(z$tkvars$subphase,state='normal')
+        tcltk::tkconfigure(z$tkvars$subphaselabel,state='normal')
     }
     z$Deriv <- FALSE
 	msf <- as.matrix(cov(z$sf)) # as.matrix() just in case z$pp = 1
@@ -42,9 +42,17 @@ phase2.1<- function(z, x, ...)
 # Instead of the preceding line,
 # the following is used for equality with earlier versions.
     z$sd <- sqrt(apply(z$sf, 2, function(x) sum(x^2) / nrow(z$sf) - mean(x)^2))
-    z$sd[z$fixed] <- 0
-	z$standardization <-
+	if (!z$gmm) 
+	{
+   	z$sd[z$fixed] <- 0
+	  z$standardization <-
 						1/sqrt(diag(as.matrix(z$dinvv %*% msf %*% t(z$dinvv))))
+	}
+	else
+	{
+	  z$sd[which(z$fixed & !z$gmmEffects)] <- 0
+	  z$standardization <- 1/sqrt(diag(as.matrix(z$dinvv %*% msf %*% t(z$dinvv))))
+	}
     Report(paste("standardization = ", round(z$standardization,4)), cf)
 	if (sum(z$fixed) < z$pp)
 	{
@@ -240,32 +248,6 @@ doIterations<- function(z, x, subphase,...)
 				## running faster with no tcl/tk
 			}
 		}
-		if ((z$nit <= 10) || (z$nit %% z$writefreq ==0))
-		{
-			DisplayIteration(z)
-			if (is.batch())
-			{
-				val <- getProgressBar(z$pb)
-				increment <- ifelse(z$nit <= 10, 1, z$writefreq)
-				Report(paste('Phase ', z$Phase, ' Subphase ', subphase,
-						' Iteration ', z$nit,' Progress: ',
-						round((increment + val) / z$pb$pbmax * 100),
-						'%\n', sep = ''))
-				z$pb <- setProgressBar(z$pb, val + increment)
-			}
-			else
-			{
-				if (z$nit>1)
-				{
-					DisplayDeviations(z, fra)
-				}
-				if  (z$nit %% z$writefreq == 0)
-				{
-					val <- getProgressBar(z$pb)
-					z$pb <-setProgressBar(z$pb, val + z$writefreq)
-				}
-			}
-		}
 		zsmall$nit <- z$nit
 		if (x$dolby) {zsmall$Deriv <- TRUE} ## include scores in FRAN
 		if (z$int == 1) ## then no parallel runs at this level
@@ -312,6 +294,33 @@ doIterations<- function(z, x, subphase,...)
 			}
 
 		}
+		
+		if ((z$nit <= 10) || (z$nit %% z$writefreq ==0))
+		{
+			DisplayIteration(z)
+			if (is.batch())
+			{
+				val <- getProgressBar(z$pb)
+				increment <- ifelse(z$nit <= 10, 1, z$writefreq)
+				Report(paste('Phase ', z$Phase, ' Subphase ', subphase,
+						' Iteration ', z$nit,' Progress: ',
+						round((increment + val) / z$pb$pbmax * 100),
+						'%\n', sep = ''))
+				z$pb <- setProgressBar(z$pb, val + increment)
+			}
+			else
+			{
+				if (z$nit>1)
+				{
+					DisplayDeviations(z, fra)
+				}
+				if  (z$nit %% z$writefreq == 0)
+				{
+					val <- getProgressBar(z$pb)
+					z$pb <- setProgressBar(z$pb, val + z$writefreq)
+				}
+			}
+		}
 		## setup check for end of phase. either store or calculate
 		if (z$nit %% 2 == 1)
 		{
@@ -348,9 +357,18 @@ doIterations<- function(z, x, subphase,...)
 		{
 			if (z$pp > sum(z$fixed))
 			{
-				maxRatio <-
-					max(sqrt((t(fra[!z$fixed]) %*% z$sf.invcov %*% fra[!z$fixed]) /
-							(z$pp-sum(z$fixed))))
+			  if(!z$gmm)
+			  {
+			    maxRatio <-
+			      max(sqrt((t(fra[!z$fixed]) %*% z$sf.invcov %*% fra[!z$fixed]) /
+			                 (z$pp-sum(z$fixed))))			    
+			  }
+			  else
+			  {
+			    maxRatio <-
+			      max(sqrt((t(fra[!z$fixed & !z$gmmEffects]) %*% z$sf.invcov %*% fra[!z$fixed & !z$gmmEffects]) /
+			                 (z$pp-sum(!z$fixed & !z$gmmEffects)))) 
+			   }
 				# the max() is just to turn the (1,1) matrix into a number.
 			}
 			else
@@ -382,20 +400,45 @@ doIterations<- function(z, x, subphase,...)
 			{
 				if (x$standardizeWithTruncation)
 				{
-					changestep <- (as.vector(z$dinvv %*% fra))*pmin(z$standardization, 1)
+				  if (!z$gmm)
+				  {
+				    changestep <- (as.vector(z$dinvv %*% fra))*pmin(z$standardization, 1)
+				  }
+				  else
+				  {
+				    change <- (as.vector(z$dinvv %*% fra))*pmin(z$standardization, 1)
+				    changestep <- rep(0,z$pp)
+				    changestep[!z$gmmEffect] <- change
+				  }
 				}
 				else
 				{
-					changestep <- (as.vector(z$dinvv %*% fra))*z$standardization
+				  if (!z$gmm)
+				  {
+				    changestep <- (as.vector(z$dinvv %*% fra))*z$standardization
+				  }
+				  else
+				  {
+				    changestep <- (as.vector(z$dinvv %*% fra))*z$standardization
+				    changestep <- rep(0,z$pp)
+				    changestep[!z$gmmEffect] <- change
+		
+				  }
 				}
 			}
 		}
 		else
 		{
-			if (x$diagg)
+			if (x$diagg & !z$gmm)
 			{
 				changestep <- fra / diag(z$dfra)
 			}
+		  	else if (z$gmm)
+		  	{
+			    change <- (as.vector(z$dinvv %*% fra))
+			    changestep <- rep(0,z$pp)
+			    changestep[!z$gmmEffect] <- change 
+			}
 			else
 			{
 				changestep <- as.vector(z$dinvv %*% fra)
