@@ -84,6 +84,7 @@ protected:
 		const Network * pSummationTieNetwork);
 	virtual double tieStatistic(int alter);
 	virtual void cleanupStatisticCalculation();
+	inline int settingsStepType() const;
 
 	inline ConfigurationTable * pTwoPathTable() const;
 	inline ConfigurationTable * pReverseTwoPathTable() const;
@@ -108,6 +109,9 @@ private:
 	NetworkCache * lpNetworkCache;
 	int lego;
 
+	// Stores the values of the stepType (settings model)
+	int lstepTypeVal;
+
 	// The number of two-paths from the ego to each of the alters
 	ConfigurationTable * lpTwoPathTable;
 
@@ -175,6 +179,15 @@ int NetworkEffect::ego() const
 }
 
 
+/**
+ * Returns the stepType of the current ministep.
+ */
+int NetworkEffect::settingsStepType() const
+{
+	return this->lstepTypeVal;
+}
+
+
 /**
  * Returns the table storing the number of two-paths from the ego to
  * each of the alters.
