@@ -25,6 +25,11 @@ HigherFilter::HigherFilter(const NetworkVariable * pOwnerVariable,
 	const NetworkVariable * pOtherVariable) :
 		NetworkDependentFilter(pOwnerVariable, pOtherVariable)
 {
+	const NetworkVariable * pNetworkVariable1 = this->pVariable();
+	const NetworkVariable * pNetworkVariable2 = this->pOtherVariable();
+	lsymmetric <- pNetworkVariable2->symmetric() && !pNetworkVariable1->symmetric();
+//  The extra steps for a symmetric other network are superfluous
+//  if the owner network is also symmetric.
 }
 
 
@@ -56,6 +61,27 @@ void HigherFilter::filterPermittedChanges(int ego, bool * permitted)
 
 		iter2.next();
 	}
+	
+	if (this->lsymmetric)
+	{
+		IncidentTieIterator iter1 = pNetwork1->outTies(ego);
+		IncidentTieIterator iter2 = pNetwork2->inTies(ego);
+
+		while (iter2.valid())
+		{
+			while (iter1.valid() && iter1.actor() < iter2.actor())
+			{
+				iter1.next();
+			}
+
+			if (iter1.valid() && iter1.actor() == iter2.actor())
+			{
+				permitted[iter1.actor()] = false;
+			}
+
+			iter2.next();
+		}
+	}
 }
 
 
@@ -73,7 +99,15 @@ bool HigherFilter::validMiniStep(const NetworkChange * pMiniStep)
 	int i = pMiniStep->ego();
 	int j = pMiniStep->alter();
 
-	return !pNetwork1->tieValue(i, j) || !pNetwork2->tieValue(i, j);
+	if  (this->lsymmetric)
+	{
+		return !pNetwork1->tieValue(i, j) || 
+				!(pNetwork2->tieValue(i, j) || pNetwork2->tieValue(j, i)) ;
+	}
+	else
+	{
+		return !pNetwork1->tieValue(i, j) || !pNetwork2->tieValue(i, j) ;
+	}
 }
 
 }
