@@ -28,6 +28,9 @@ public:
 
 	virtual void filterPermittedChanges(int ego, bool * permitted);
 	virtual bool validMiniStep(const NetworkChange * pMiniStep);
+	
+private:
+	bool lsymmetric;
 };
 
 }
